@@ -820,6 +820,11 @@ QString Fastsms::capitalizeIfNeeded(QString sWord)
                     break;
                 }
             }
+            else if(m_dict->isSymbol(smsText.at(i)))
+            {
+                bToUpper = false;
+                break;
+            }
         }
 
         if(bToUpper || m_bRememberUppercase)
@@ -935,6 +940,14 @@ void Fastsms::sendSMS()
 
     if(!m_smsEdit->toPlainText().isEmpty() && !m_phoneNumber->text().isEmpty())
     {
+        //Message box
+        #if defined(Q_WS_MAEMO_5)
+
+        QMaemo5InformationBox::information(this, "Sending...",
+                                           QMaemo5InformationBox::DefaultTimeout);
+        #endif
+        //
+
         if(!lstMsgAccountId.isEmpty())
         {
             qDebug() << "SMS text" << m_smsEdit->toPlainText();
@@ -945,13 +958,6 @@ void Fastsms::sendSMS()
 
                 if(isSmsAccount)
                 {
-                    //Message box
-                    #if defined(Q_WS_MAEMO_5)
-
-                    QMaemo5InformationBox::information(this, "Sending...",
-                                                       QMaemo5InformationBox::DefaultTimeout);
-                    #endif
-                    //
                     QMessage myMessage;
                     myMessage.setType(QMessage::Sms);
                     myMessage.setParentAccountId(lstMsgAccountId[i]);
@@ -1030,7 +1036,7 @@ void Fastsms::chageInputStyle()
     }
     else if(action->data() == IN_STYLE_FW_ON)
     {
-        //Rest FastWrite state
+        //Restore FastWrite state
         ui->btZero->click();
         ui->btDelChar->click();
         //
