@@ -97,10 +97,8 @@ private:
     int m_nSMSCount;
     ///new code
     bool m_bFastInput;
-    bool m_bMustCapitalize;
     int m_nInputSyle;
-    bool m_bNewChar;
-    bool m_bWasCapitalized;
+    bool m_bRememberUppercase;
     QString m_sCapitalization;
     QTimer *timerNewChar;
     bool m_bTimerNewChar;
